@@ -37,4 +37,10 @@ class InstallMonitoringAgentRequest(RpcRequest):
 		return self.get_query_params().get('Force')
 
 	def set_Force(self,Force):
-		self.add_query_param('Force',Force)
\ No newline at end of file
+		self.add_query_param('Force',Force)
+
+	def get_InstallCommand(self):
+		return self.get_query_params().get('InstallCommand')
+
+	def set_InstallCommand(self,InstallCommand):
+		self.add_query_param('InstallCommand',InstallCommand)
\ No newline at end of file
